@@ -3,9 +3,7 @@ if [ -x /usr/bin/update-desktop-database ]; then
   /usr/bin/update-desktop-database /usr/share/applications >/dev/null 2>&1
 fi
 
-( cd usr/share/doc/HTML/en/kweather ; rm -rf common )
-( cd usr/share/doc/HTML/en/kweather ; ln -sf /usr/share/doc/HTML/en/common common )
-( cd usr/share/doc/HTML/en/amor ; rm -rf common )
-( cd usr/share/doc/HTML/en/amor ; ln -sf /usr/share/doc/HTML/en/common common )
 ( cd usr/share/doc/HTML/en/kteatime ; rm -rf common )
 ( cd usr/share/doc/HTML/en/kteatime ; ln -sf /usr/share/doc/HTML/en/common common )
+( cd usr/share/doc/HTML/en/amor ; rm -rf common )
+( cd usr/share/doc/HTML/en/amor ; ln -sf /usr/share/doc/HTML/en/common common )
